Index: tools/gn/target_generator.cc |
diff --git a/tools/gn/target_generator.cc b/tools/gn/target_generator.cc |
index d38dbd938770bcae8b9858ce5ee30c2f54b99abf..12d09fca1527092d16ff2b249a47e72ce739fe14 100644 |
--- a/tools/gn/target_generator.cc |
+++ b/tools/gn/target_generator.cc |
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() { |
void TargetGenerator::FillInputs() { |
const Value* value = scope_->GetValue(variables::kInputs, true); |
if (!value) { |
// Older versions used "inputs". Allow use of this variable until |
// all callers are updated. |
// TODO(brettw) remove this eventually. |
- value = scope_->GetValue("inputs", true); |
+ value = scope_->GetValue("source_prereqs", true); |
if (!value) |
return; |
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() { |
const Value* value = scope_->GetValue(variables::kInputs, true); |
if (!value) { |
- // Older versions used "inputs". Allow use of this variable until |
+ // Older versions used "source_prereqs". Allow use of this variable until |
// all callers are updated. |
// TODO(brettw) remove this eventually. |